@@ -51,7 +51,7 @@ extern "C"
    * version number.  Used together with gsasl_check_version() to
    * verify header file and run-time library consistency.
    */
-# define GSASL_VERSION "1.6.0"
+# define GSASL_VERSION "1.7.0"
 
   /**
    * GSASL_VERSION_MAJOR
@@ -73,7 +73,7 @@ extern "C"
    *
    * Since: 1.1
    */
-# define GSASL_VERSION_MINOR 6
+# define GSASL_VERSION_MINOR 7
 
   /**
    * GSASL_VERSION_PATCH
@@ -95,7 +95,7 @@ extern "C"
    *
    * Since: 1.1
    */
-# define GSASL_VERSION_NUMBER 0x010600
+# define GSASL_VERSION_NUMBER 0x010700
 
   /* RFC 2222: SASL mechanisms are named by strings, from 1 to 20
    * characters in length, consisting of upper-case letters, digits,
@@ -135,7 +135,8 @@ extern "C"
    * @GSASL_NO_PIN: Could not get required SecurID PIN.
    * @GSASL_NO_SERVICE: Could not get required service name.
    * @GSASL_NO_HOSTNAME: Could not get required hostname.
-   * @GSASL_NO_CB_TLS_UNIQUE: Could not get required tls-unique CB.
+   * @GSASL_NO_SAML20_IDP_IDENTIFIER: Could not get required SAML IdP.
+   * @GSASL_NO_SAML20_REDIRECT_URL: Could not get required redirect URL.
    * @GSASL_GSSAPI_RELEASE_BUFFER_ERROR: GSS-API library call error.
    * @GSASL_GSSAPI_IMPORT_NAME_ERROR: GSS-API library call error.
    * @GSASL_GSSAPI_INIT_SEC_CONTEXT_ERROR: GSS-API library call error.
@@ -185,7 +186,8 @@ extern "C"
     GSASL_NO_PIN = 57,
     GSASL_NO_SERVICE = 58,
     GSASL_NO_HOSTNAME = 59,
-    GSASL_NO_CB_TLS_UNIQUE = 65,
+    GSASL_NO_SAML20_IDP_IDENTIFIER = 65,
+    GSASL_NO_SAML20_REDIRECT_URL = 66,
     /* Mechanism specific errors. */
     GSASL_GSSAPI_RELEASE_BUFFER_ERROR = 37,
     GSASL_GSSAPI_IMPORT_NAME_ERROR = 38,
@@ -299,12 +301,15 @@ extern "C"
    * @GSASL_SCRAM_SALT: Salt for password-to-key hashing.
    * @GSASL_SCRAM_SALTED_PASSWORD: Pre-computed salted SCRAM key,
    *   to avoid re-computation and storing passwords in the clear.
-   * @GSASL_CB_TLS_UNIQUE: Base64 encoded tls-unique channel binding.
+   * @GSASL_SAML20_IDP_IDENTIFIER: SAML20 user IdP URL.
+   * @GSASL_SAML20_REDIRECT_URL: SAML20 challenge from server to client.
+   * @GSASL_SAML20_AUTHENTICATE_IN_BROWSER: Request to perform SAML20.
    * @GSASL_VALIDATE_SIMPLE: Request for simple validation.
    * @GSASL_VALIDATE_EXTERNAL: Request for validation of EXTERNAL.
    * @GSASL_VALIDATE_ANONYMOUS: Request for validation of ANONYMOUS.
    * @GSASL_VALIDATE_GSSAPI: Request for validation of GSSAPI/GS2.
    * @GSASL_VALIDATE_SECURID: Reqest for validation of SecurID.
+   * @GSASL_VALIDATE_SAML20: Reqest for validation of SAML20.
    *
    * Callback/property types.
    */
@@ -328,13 +333,17 @@ extern "C"
     GSASL_SCRAM_ITER = 15,
     GSASL_SCRAM_SALT = 16,
     GSASL_SCRAM_SALTED_PASSWORD = 17,
-    GSASL_CB_TLS_UNIQUE = 18,
+    GSASL_SAML20_IDP_IDENTIFIER = 18,
+    GSASL_SAML20_REDIRECT_URL = 19,
+    /* Client callbacks. */
+    GSASL_SAML20_AUTHENTICATE_IN_BROWSER = 250,
     /* Server validation callback properties. */
     GSASL_VALIDATE_SIMPLE = 500,
     GSASL_VALIDATE_EXTERNAL = 501,
     GSASL_VALIDATE_ANONYMOUS = 502,
     GSASL_VALIDATE_GSSAPI = 503,
-    GSASL_VALIDATE_SECURID = 504
+    GSASL_VALIDATE_SECURID = 504,
+    GSASL_VALIDATE_SAML20 = 505
   } Gsasl_property;
 
   /**
